import type { SyntaxHighlighterProps } from 'src/types/shiki'
import React from 'react'
import { Text, View } from 'react-native'
import githubDark from 'shiki/themes/github-dark.mjs'
import { useSyntaxHighlighter } from '../../hooks/useSyntaxHighlighter'

function SyntaxHighlighter({ text, language, languageId, theme = githubDark }: SyntaxHighlighterProps) {
  const { tokens, error, isLoading } = useSyntaxHighlighter({
    text,
    language,
    languageId,
    theme,
  })

  if (error) {
    return (
      <Text style={{ color: '#ff6b6b', fontFamily: 'monospace' }}>
        Error:
        {error}
      </Text>
    )
  }

  if (isLoading) {
    return <Text style={{ color: '#666666', fontFamily: 'monospace' }}>Loading...</Text>
  }

  return (
    <View>
      {tokens.map((line, lineIndex) => (
        <View key={`line-${lineIndex}`} style={{ flexDirection: 'row', flexWrap: 'wrap' }}>
          {line.map((token, tokenIndex) => (
            <Text
              key={`${lineIndex}-${tokenIndex}`}
              style={{
                color: token.color || '#000000',
                fontFamily: 'monospace',
                fontStyle: token.fontStyle as unknown as 'normal' | 'italic',
              }}
            >
              {token.content.replace(/ /g, '\u00A0')}
            </Text>
          ))}
          <Text
            style={{
              color: theme === githubDark ? '#000000' : '#FFFFFF',
              fontFamily: 'monospace',
            }}
          >
            {'\n'}
          </Text>
        </View>
      ))}
    </View>
  )
}

export default SyntaxHighlighter
